Learn R Programming

shinyhelper (version 0.3.2)

observe_helpers: Observe Helper Action Buttons

Description

Function to show a modal dialog, observing each of the help icons in the app.

Usage

observe_helpers(session = shiny::getDefaultReactiveDomain(),
  help_dir = "helpfiles", withMathJax = FALSE)

Arguments

session

The session object in your shiny app.

help_dir

A character string of the directory containing your helpfiles.

withMathJax

If TRUE the MathJax library is added to allow for math expressions in markdown content.

Examples

Run this code
# NOT RUN {
server <- function(input, output, session){

  # use anywhere in your server.R script
  observe_helpers()
  
  # rest of server.R
  # ...
  # ...
}

# }

Run the code above in your browser using DataLab