powered by
Function to show a modal dialog, observing each of the help icons in the app.
observe_helpers(session = shiny::getDefaultReactiveDomain(), help_dir = "helpfiles", withMathJax = FALSE)
The session object in your shiny app.
A character string of the directory containing your helpfiles.
If TRUE the MathJax library is added to allow for math expressions in markdown content.
TRUE
# NOT RUN { server <- function(input, output, session){ # use anywhere in your server.R script observe_helpers() # rest of server.R # ... # ... } # }
Run the code above in your browser using DataLab